searchData={"items":[{"type":"module","title":"ExEmail","doc":"`ExEmail` implements a parser and validator for email addresses according to the\nABNF rules defined in the following RFCs:\n\n- [RFC5321 - Simple Mail Transfer Protocol](https://tools.ietf.org/rfc/rfc5321.txt)\n- [RFC6531 - SMTP Extension for Internationalized](https://tools.ietf.org/rfc/rfc6531.txt)\n- [RFC6532 - Internationalized Email Headers](https://tools.ietf.org/rfc/rfc6532.txt)\n\nWhen parsing emails addressed to IP addresses, the domain part is parsed via the rules\ndefined in\n[RFC3986: Uniform Resource Identifier (URI): Generic Syntax](https://tools.ietf.org/rfc/rfc3986.txt).","ref":"ExEmail.html"},{"type":"module","title":"Notes - ExEmail","doc":"- `ExEmail` is a reimplementation of [`:email_validator`](https://hex.pm/packages/email_validator)\n  in Elixir. It's a fantastic library.\n- ABNF rules are compiled using `AbnfParsec`. Because it's built on top of `NimbleParsec`,\n  the ABNF shipped with this library differs from the relevant RFCs in specific ways. ABNF\n  assumes that when a rule defines multiple choices, that each choice can be attempted, and\n  then backtracked to the last matching rule; `NimbleParsec` does not support backtracking,\n  so rules must be defined such that the most appropriate rule is most likely to be matched\n  first.","ref":"ExEmail.html#module-notes"},{"type":"type","title":"ExEmail.domain_part/0","doc":"","ref":"ExEmail.html#t:domain_part/0"},{"type":"type","title":"ExEmail.local_part/0","doc":"","ref":"ExEmail.html#t:local_part/0"},{"type":"function","title":"ExEmail.parse/1","doc":"Parses an email address into a tuple of `{:ok, {local_part, domain_part}}`, or\n`{:error, ExEmail.Error.t()}`.","ref":"ExEmail.html#parse/1"},{"type":"function","title":"Examples - ExEmail.parse/1","doc":"``` elixir\niex> ExEmail.parse(\"a@example.com\")\n{:ok, {\"a\", \"example.com\"}}\niex> ExEmail.parse(\"a@[127.0.0.1]\")\n{:ok, {\"a\", \"[127.0.0.1]\"}}\niex> ExEmail.parse(\"a@[IPv6:::1]\")\n{:ok, {\"a\", \"[IPv6:::1]\"}}\n\niex> ExEmail.parse(\"@example.com\")\n{:error, ExEmail.Error.new(\"parse error\", \"@example.com\")}\n```","ref":"ExEmail.html#parse/1-examples"},{"type":"type","title":"ExEmail.t/0","doc":"A tuple of the local and domain parts of an email address; parsing the address\n`alice@example.com` returns `{\"alice\", \"example.com\"}`.","ref":"ExEmail.html#t:t/0"},{"type":"function","title":"ExEmail.validate/1","doc":"Validates the format of an email address, returning either `:ok` or a\ntuple of `{:error, ExEmail.Error.t()}`.","ref":"ExEmail.html#validate/1"},{"type":"function","title":"Examples - ExEmail.validate/1","doc":"``` elixir\niex> ExEmail.validate(\"a@example.com\")\n:ok\n\niex> ExEmail.validate(\"@example.com\")\n{:error, ExEmail.Error.new(\"parse error\", \"@example.com\")}\n```","ref":"ExEmail.html#validate/1-examples"},{"type":"exception","title":"ExEmail.Error","doc":"","ref":"ExEmail.Error.html"},{"type":"function","title":"ExEmail.Error.new/2","doc":"","ref":"ExEmail.Error.html#new/2"},{"type":"type","title":"ExEmail.Error.t/0","doc":"","ref":"ExEmail.Error.html#t:t/0"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2025 synchronal.dev\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may\nnot use this file except in compliance with the License. You may obtain\na copy of the License at\n\n \n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"},{"type":"extras","title":"Change log","doc":"# Change log","ref":"changelog.html"},{"type":"extras","title":"v0.1.2 - Change log","doc":"- Fix error handling when address bytes size is too large.","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Change log","doc":"- Add documentation.","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Change log","doc":"- Initial release.","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}